<?php
/**
 * Example module
 *
 * Use this module as template for your own modules
 */

/**
 * You can create simple functions and register them.
 */
function module_hello_world()
{
    echo '<p>Hello World Function!</p>';
}

/**
 * Register your function
 *
 * The first parameter is the trigger name. The second parameter is the function name.
 */
module::register_trigger('admin_homepage', 'module_hello_world');



/**
 * You can also create a class and register methods of that class.
 */
class HelloWorld
{
    /**
     * Register class methods in class constructor
     */
    public function __construct()
    {
        /**
         * Register the object and the method
         *
         * The second parameter takes an array of the object and the method name.
         */
        module::register_trigger('admin_homepage', array(&$this, 'sayHello'));
        module::register_trigger('login_form_validation', array(&$this, 'myLogin'));

    }

    /**
     * A simple example method to output some text
     */
    public function sayHello()
    {
        echo '<p>Hello World Class!</p>';
    }


    /**
     * Example function that hooks into the login process - If the entered email
     * is info@example.com, display an error message.
     */
    public function myLogin()
    {
    	// Do nothing if the form hasn't been submited
    	if (!isset($_POST['loginemail'])) {
    		return false;
    	}

    	// Use variable $show_login and $error_message and also $configuration
    	global $show_login;
    	global $error_message;
        global $configuration;

        // Load the module text (from language file)
        $text = $configuration['module_text']['helloworld'];


        // If the user has entered the email address info@example.com, display an error message
        if ($_POST['loginemail'] == 'info@example.com') {
    		$show_login = false;
    		$error_message .= $text['login_error'];
        }
    }
}

/**
 * Instantiate class
 */
new HelloWorld;